unit MainUnit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  FileCtrl, StdCtrls, ExtCtrls, ComCtrls;

type
  TMainForm = class(TForm)
    Label2: TLabel;
    cbForever: TCheckBox;
    ProcGenButton: TButton;
    msActive: TEdit;
    msInactive: TEdit;
    msActiveUpDown: TUpDown;
    msInactiveUpDown: TUpDown;
    lblHz: TLabel;
    Memo1: TMemo;
    mVedit: TEdit;
    Label1: TLabel;
    Label3: TLabel;
    mVupDown: TUpDown;
    Edit1: TEdit;
    Label4: TLabel;
    mVIdleUpDown: TUpDown;
    procedure ProcGenButtonClick(Sender: TObject);
  protected
    ClockHz: Double;
    { Private declarations }
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;





implementation

{$R *.DFM}

uses
  Math,
  AIOUSB;

procedure TMainForm.ProcGenButtonClick(Sender: TObject);
  var
    volts, idleVolts : double;
    inactive : integer;
    active : integer;
    SampleData : array of Word;
    i : integer;
    Status: longword;

    procedure HandleError(s:longword; msg:string='');
    begin
      memo1.lines.add(IntToStr(s)+ ' -- ' + msg);
    end;

begin
    ClockHz := 1000.0;
    volts := mVupDown.Position / 1000.0;
    idleVolts := mVIdleUpDown.Position /1000.0;
    active := msActiveUpDown.Position;
    inactive := msInactiveUpDown.Position;

    Status := AIOUSB.AIOUSB_ReloadDeviceLinks;
    if status <> ERROR_SUCCESS then HandleError(Status, 'ReloadDeviceLinks');

    Status := AIOUSB.DACSetBoardRange(AIOUSB.diOnly, 3);
    if status <> ERROR_SUCCESS then HandleError(Status, 'DACSetBoardRange');

    Status := AIOUSB.GenericVendorWrite(AIOUSB.diOnly, $C7, 1, 256, 0, nil);    // buffer length
    if status <> ERROR_SUCCESS then HandleError(Status, 'GenericVendorWrite - buffer length setting 15');

    SetLength(SampleData, inactive + active);
    for i := 0 to inactive -1 do
      SampleData[i] := round((idleVolts + 10.0) / 20.0 * 65536.0);
    for i := inactive to inactive+active-1 do
      SampleData[i] := round((volts + 10.0) / 20.0 * 65536.0);

    Status := AIOUSB.GenericVendorWrite(AIOUSB.diOnly, $C7, $0101, 0, 0, nil);  // DAC Set Channel Count (only 1x DAC (#0)in waveform data)
    if status <> ERROR_SUCCESS then HandleError(Status, 'GenericVendorWrite - DAC SetChannelCount');

    // Status := AIOUSB.DACOutputSetCount(AIOUSB.diOnly, 1); // just 1 channel of waveform
    // if Status <> ERROR_SUCCESS then HandleError(Status, 'DACOutputSetCount');

    cbForever.Checked := True;
    repeat
        Status := AIOUSB.DACOutputProcess(AIOUSB.diOnly, ClockHz, Length(SampleData), @SampleData[0]);
        if status <> ERROR_SUCCESS then HandleError(Status, 'DACOutputProcess');
        Application.ProcessMessages;
    until cbForever.Checked = FALSE;
end;

end.
